@@ -14,6 +14,8 @@ _ = gpodder.gettext
 __title__ = _('Search for new episodes on startup')
 __description__ = _('Starts the search for new episodes on startup')
 __authors__ = 'Bernd Schlapsi <brot@gmx.info>'
+__doc__ = 'http://wiki.gpodder.org/wiki/Extensions/SearchEpisodeOnStartup'
+__payment__ = 'https://flattr.com/submit/auto?user_id=BerndSch&url=http://wiki.gpodder.org/wiki/Extensions/SearchEpisodeOnStartup'
 __category__ = 'interface'
 __only_for__ = 'gtk'
 
