@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # gPodder - A media aggregator and podcast client
-# Copyright (c) 2005-2015 Thomas Perl and the gPodder Team
+# Copyright (c) 2005-2016 Thomas Perl and the gPodder Team
 #
 # gPodder is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,10 +20,10 @@
 # This metadata block gets parsed by setup.py - use single quotes only
 __tagline__   = 'Media aggregator and podcast client'
 __author__    = 'Thomas Perl <thp@gpodder.org>'
-__version__   = '3.8.5'
-__date__      = '2015-12-01'
-__relname__   = 'Casting Agents and Cowgirls'
-__copyright__ = '© 2005-2015 Thomas Perl and the gPodder Team'
+__version__   = '3.9.0'
+__date__      = '2016-02-03'
+__relname__   = 'Helium Levitator'
+__copyright__ = '© 2005-2016 Thomas Perl and the gPodder Team'
 __license__   = 'GNU General Public License, version 3 or later'
 __url__       = 'http://gpodder.org/'
 
@@ -83,12 +83,10 @@ del sqlite3
 # The User-Agent string for downloads
 user_agent = 'gPodder/%s (+%s)' % (__version__, __url__)
 
-# Are we running in GUI, MeeGo 1.2 Harmattan or console mode?
+# Are we running in GUI or console mode?
 class UI(object):
     def __init__(self):
-        self.harmattan = False
         self.gtk = False
-        self.qml = False
         self.cli = False
 
 
@@ -129,7 +127,7 @@ if ui.win32:
         bindtextdomain(textdomain, locale_dir)
         del bindtextdomain
     except:
-        # Ignore for QML UI or missing glade module
+        # Ignore for missing glade module
         pass
 del t
 
@@ -224,19 +222,3 @@ def load_plugins():
             __import__(plugin)
         except Exception, e:
             print >>sys.stderr, 'Cannot load plugin: %s (%s)' % (plugin, e)
-
-
-def detect_platform():
-    global ui
-
-    try:
-        etc_issue = open('/etc/issue').read()
-    except Exception, e:
-        etc_issue = ''
-
-    ui.harmattan = ('MeeGo 1.2 Harmattan' in etc_issue)
-
-    if ui.harmattan and ENV_HOME not in os.environ:
-        new_home = os.path.expanduser(os.path.join('~', 'MyDocs', 'gPodder'))
-        set_home(os.path.expanduser(new_home))
-
