@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # gPodder - A media aggregator and podcast client
-# Copyright (c) 2005-2015 Thomas Perl and the gPodder Team
+# Copyright (c) 2005-2016 Thomas Perl and the gPodder Team
 #
 # gPodder is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -28,7 +28,6 @@ from gpodder import config
 from gpodder import dbsqlite
 from gpodder import extensions
 from gpodder import model
-from gpodder import flattr
 
 
 class Core(object):
@@ -53,9 +52,6 @@ class Core(object):
         # Update the current device in the configuration
         self.config.mygpo.device.type = util.detect_device_type()
 
-        # Initialize Flattr integration
-        self.flattr = flattr.Flattr(self.config.flattr)
-
     def shutdown(self):
         # Notify all extensions that we are being shut down
         gpodder.user_extensions.shutdown()
