@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # gPodder - A media aggregator and podcast client
-# Copyright (c) 2005-2015 Thomas Perl and the gPodder Team
+# Copyright (c) 2005-2016 Thomas Perl and the gPodder Team
 #
 # gPodder is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -179,7 +179,7 @@ class Exporter(object):
             FREE_DISK_SPACE_AFTER = 1024*512
             path = os.path.dirname(self.filename) or os.path.curdir
             available = util.get_free_disk_space(path)
-            if available < 2*len(data)+FREE_DISK_SPACE_AFTER:
+            if available != -1 and available < 2*len(data)+FREE_DISK_SPACE_AFTER:
                 # On Windows, if we have zero bytes available, assume that we have
                 # not had the win32file module available + assume enough free space
                 if not gpodder.ui.win32 or available > 0:
