@@ -1,3 +1,4 @@
+import dbus.exceptions
 
 class SessionBus(object):
     def __init__(self, *args, **kwargs):
@@ -9,3 +10,4 @@ class SessionBus(object):
     def name_has_owner(self, *args, **kwargs):
         return False
 
+SystemBus = SessionBus
